<?php
/*
Plugin Name:  Affiliate Link Cloaker
Plugin URI:  http://www.brewsterware.com/affiliate-link-cloaker-wordpress-plugin.html
Version: 1.00.01
Description: Generates geo targetted cloaked affiliate links. Links can either be placed manually in the post/page content, or if a keyword/phrase is specified links will be inserted automatically.
Author: Joe Brewer
Author URI:  http://www.brewsterware.com/
*/

/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

// constants for the flag field in the link table
define('ALC_ACTIVE', 0x0001);
define('ALC_NOFOLLOW', 0x0002);
define('ALC_OPENNEWWINDOW', 0x0004);
define('ALC_COUNTREDIRECTS', 0x0008);

define('ALC_DEFAULTURLTRIGGER', 'recommends');

global $alc_db_version;
$alc_db_version = 1;

require_once('links.php');
require_once('redirect.php');
require_once('interface.php');

register_activation_hook(__FILE__, 'alc_install');
register_uninstall_hook(__FILE__, 'alc_uninstall');

function alc_install()
{
	global $wpdb, $table_prefix, $alc_db_version;
	
	$tables["{$table_prefix}alc_link"] = "CREATE TABLE `{$table_prefix}alc_link` (
			`id` int(10) unsigned NOT NULL auto_increment,
			`redirectType` enum('300','301','302','303','307') NOT NULL default '302',
			`maxReplacements` smallint(5) unsigned NOT NULL default '0',
			`flags` tinyint(4) NOT NULL,
			`titleText` varchar(128) NOT NULL,
			`searchText` varchar(128) NOT NULL,
			`urlSuffix` varchar(128) NOT NULL,
			`replacementOrder` int(11) NOT NULL default '0',
			PRIMARY KEY (`id`),
			UNIQUE KEY `urlSuffix` (`urlSuffix`)
			) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";

	$tables["{$table_prefix}alc_address"] = "CREATE TABLE `{$table_prefix}alc_address` (
			`id` int(10) unsigned NOT NULL auto_increment,
			`linkId` int(10) unsigned NOT NULL,
			`default` enum('Yes','No') NOT NULL default 'No',
			`country` varchar(2) NOT NULL,
			`address` varchar(256) NOT NULL,
			PRIMARY KEY (`id`),
			KEY `linkId` (`linkId`)
			) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
	
	$tables["{$table_prefix}alc_redirectlog"] = "CREATE TABLE `{$table_prefix}alc_redirectlog` (
			`addressId` int(10) unsigned NOT NULL,
			`redirectDateTime` datetime NOT NULL
			) ENGINE=MyISAM DEFAULT CHARSET=utf8;";
	
	// create tables if they do not already exist
	foreach ($tables as $tableName => $tableDesign) {
		if ($wpdb->get_var("show tables like '$tableName'") != $tableName) {
			$wpdb->query($tableDesign);
		}
	}
	
	// get the current database version
	$currentDbVersion = (int)get_option('alc_db_version');
		
	// do we need to upgrade the database?
	if ($alc_db_version > $currentDbVersion) {
		// run through the upgrades version by version
		for ($version = $currentDbVersion ;
			 $version <= $alc_db_version ;
			 $version++) {
			// is this an array ?
			if (is_array($dbChanges[$version])) {
				// iterate through the changes for each version
				foreach ($dbChanges[$version] as $change) {
					if ($change) {
						$wpdb->query($change);
					}
				}
			}
		}
	
		// update the database version option
		update_option('alc_db_version', $alc_db_version);
	}
	
	add_option('alc_url_trigger', ALC_DEFAULTURLTRIGGER);
}

function alc_uninstall()
{
	global $wpdb, $table_prefix;
	
	// remove db tables
	$wpdb->query("DROP table {$table_prefix}alc_link");
	$wpdb->query("DROP table {$table_prefix}alc_address");
	$wpdb->query("DROP table {$table_prefix}alc_redirectlog");
	
	// remove options
	delete_option('alc_url_trigger');
	delete_option('alc_db_version');
}


?>